Calendar_Base
===============
This package is not meant to be used standalone. It is mean to be extended.
This package provides methods for finding and comparing calendar events.
Triggering callbacks when events are added/changed/deleted.

Install
=======
::

    pip install calendar_base
